==> php54-owncloud-8.0.3.tgz: share/owncloud/apps/firstrunwizard/l10n/fr.php <==
<?php
$TRANSLATIONS = array(
"Welcome to %s" => "Bienvenue sur %s",
"Your personal web services. All your files, contacts, calendar and more, in one place." => "Vos services web personnels. Tous vos fichiers, contacts, agendas et bien plus encore, réunis en un seul endroit.",
"Get the apps to sync your files" => "Obtenez les applications vous permettant de synchroniser vos fichiers",
"Desktop client" => "Client de bureau",
"Android app" => "Application Android",
"iOS app" => "Application iOS",
"Connect your desktop apps to %s" => "Connectez vos applications de bureau à %s",
"Connect your Calendar" => "Connectez votre calendrier",
"Connect your Contacts" => "Connectez vos contacts",
"Access files via WebDAV" => "Accédez à vos fichiers via WebDAV",
"Documentation" => "Documentation",
"There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"http://owncloud.org\">website</a>." => "Des informations complémentaires sont disponibles dans <a target=\"_blank\" href=\"%s\">la documentation</a> et sur <a target=\"_blank\" href=\"http://owncloud.org\">notre site web</a>.",
"If you like ownCloud,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud is a great open software to sync and share your files. \n\t\tYou can freely get it from http://owncloud.org\">\n\t\trecommend it to your friends</a>\n\tand <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">spread the word</a>!" => "Si vous aimez ownCloud,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud est un super logiciel libre pour synchroniser et partager vos fichiers. \n\t\tVous pouvez l'obtenir gratuitement sur http://owncloud.org\">\n\t\trecommandez le à vos amis</a>\n\tet <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">faites passer le mot</a> !"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/firstrunwizard/l10n/fr.php <==
<?php
$TRANSLATIONS = array(
"Welcome to %s" => "Bienvenue sur %s",
"Your personal web services. All your files, contacts, calendar and more, in one place." => "Vos services web personnels. Tous vos fichiers, contacts, agendas et bien plus encore, réunis en un seul endroit.",
"Get the apps to sync your files" => "Obtenez les applications vous permettant de synchroniser vos fichiers",
"Desktop client" => "Client de bureau",
"Android app" => "Application Android",
"iOS app" => "Application iOS",
"Connect your desktop apps to %s" => "Connectez vos applications de bureau à %s",
"Connect your Calendar" => "Connectez votre calendrier",
"Connect your Contacts" => "Connectez vos contacts",
"Access files via WebDAV" => "Accédez à vos fichiers via WebDAV",
"Documentation" => "Documentation",
"There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"http://owncloud.org\">website</a>." => "Des informations complémentaires sont disponibles dans <a target=\"_blank\" href=\"%s\">la documentation</a> et sur <a target=\"_blank\" href=\"http://owncloud.org\">notre site web</a>.",
"If you like ownCloud,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud is a great open software to sync and share your files. \n\t\tYou can freely get it from http://owncloud.org\">\n\t\trecommend it to your friends</a>\n\tand <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">spread the word</a>!" => "Si vous aimez ownCloud,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud est un super logiciel libre pour synchroniser et partager vos fichiers. \n\t\tVous pouvez l'obtenir gratuitement sur http://owncloud.org\">\n\t\trecommandez-le à vos amis</a>\n\tet <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">faites passer le mot</a> !"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
